//+------------------------------------------------------------------+
//|                                   Robby DSS Bressert Colored.mq4 |
//|                                                   Jaanus Jantson |
//|                          http://fx.jantson.ee; jaanus@jantson.ee |
//|                      Copyright  2008, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
#property copyright "Copyright  2008, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net/"

#property indicator_separate_window
#property indicator_minimum 0
#property indicator_maximum 100
#property indicator_buffers 5
#property indicator_color1  OrangeRed
#property indicator_width1  3
#property indicator_color2  Blue
#property indicator_width2  2
#property indicator_color3  Red
#property indicator_width3  2
#property indicator_color4  Aqua
#property indicator_width4  2
#property indicator_color5  Magenta
#property indicator_width5  2


extern int    EMA_period        = 8;
extern int    Stochastic_period = 13;
extern double levelOs           = 10;
extern double levelOb           = 90;

extern string note              = "turn on Alert = true; turn off = false";
extern bool   alertsOn          = true;
extern bool   alertsOnSlope     = true;
extern bool   alertsOnCurrent   = true;
extern bool   alertsMessage     = true;
extern bool   alertsSound       = true;
extern bool   alertsEmail       = false;
extern string soundfile         = "alert2.wav";



double DssBuffer[];
double MitBuffer[];
double DssBuffer_UP[];
double DssBuffer_DW[];
double arUp[];
double arDn[];
double slope[];
double trend[];
double smooth_coefficient;

//
//
//
//
//

int init()
{
   IndicatorBuffers(8);
   SetIndexBuffer(0,DssBuffer);                                                       SetIndexLabel(0, "DSS");
   SetIndexBuffer(1,DssBuffer_UP); SetIndexStyle(1,DRAW_ARROW); SetIndexArrow(1,159); SetIndexLabel(1, "DSS Up");
   SetIndexBuffer(2,DssBuffer_DW); SetIndexStyle(2,DRAW_ARROW); SetIndexArrow(2,159); SetIndexLabel(2, "DSS Down");
   SetIndexBuffer(3,arUp);         SetIndexStyle(3,DRAW_ARROW); SetIndexArrow(3,233); 
   SetIndexBuffer(4,arDn);         SetIndexStyle(4,DRAW_ARROW); SetIndexArrow(4,234); 
   SetIndexBuffer(5,MitBuffer);
   SetIndexBuffer(6,slope);
   SetIndexBuffer(7,trend);
   SetLevelValue(0,levelOs);
   SetLevelValue(1,levelOb);
   
   smooth_coefficient = 2.0 / (1.0 + EMA_period);
  
   IndicatorShortName ("DSS("+EMA_period+","+Stochastic_period+")");

   
   return(0);
}


int start()
{
   int i, limit, counted_bars=IndicatorCounted();
   if (counted_bars == 0)  limit = Bars - Stochastic_period;
   if (counted_bars > 0)   limit = Bars - counted_bars;
         
   //
   //
   //
   //
   //
   
   for (i=limit; i>=0; i--)
   {
   
      double HighRange = High[iHighest(NULL,0,MODE_HIGH,Stochastic_period,i)];
      double LowRange  = Low[iLowest(NULL,0,MODE_LOW,Stochastic_period,i)];
      double delta     = Close[i] - LowRange;
      double MIT       = delta/(HighRange - LowRange)*100.0;
      MitBuffer[i]     = smooth_coefficient * (MIT - MitBuffer[i+1]) + MitBuffer[i+1];
   }

   for (i = limit; i >= 0; i--)
   {
      HighRange    = MitBuffer[ArrayMaximum(MitBuffer, Stochastic_period, i)];
      LowRange     = MitBuffer[ArrayMinimum(MitBuffer, Stochastic_period, i)];
      delta        = MitBuffer[i] - LowRange;
      double DSS   = delta/(HighRange - LowRange)*100.0;
      DssBuffer[i] = smooth_coefficient * (DSS - DssBuffer[i+1]) + DssBuffer[i+1];
   }

   for (i = limit; i >= 0; i--)
   {
      DssBuffer_UP[i] = EMPTY_VALUE;
      DssBuffer_DW[i] = EMPTY_VALUE;
      slope[i] = slope[i+1];
      
         if(DssBuffer[i] > DssBuffer[i+1])    slope[i] =  1; 
         if(DssBuffer[i] < DssBuffer[i+1])    slope[i] = -1;
         if(slope[i] == 1)  DssBuffer_UP[i] = DssBuffer[i];
         if(slope[i] ==-1)  DssBuffer_DW[i] = DssBuffer[i];
      
      //
      //
      //
      //
      //
      
      trend[i] = trend[i+1];
         if(DssBuffer[i] <= levelOs) trend[i] =  1;  
         if(DssBuffer[i] >= levelOb) trend[i] = -1;  
         
      arUp[i] = EMPTY_VALUE;
      arDn[i] = EMPTY_VALUE;
      if (trend[i]!= trend[i+1])
      if (trend[i] == 1)
            arUp[i] = DssBuffer[i];
      else  arDn[i] = DssBuffer[i];
      
      } 
    
      //
      //
      //
      //
      //
      
      if (alertsOn)
      {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1;

      //
      //
      //
      //
      //

      if (alertsOnSlope)
      {
         if (slope[whichBar] != slope[whichBar+1])
         if (slope[whichBar] == 1)
               doAlert("slope changed up");
         else  doAlert("slope changed down");       
      }
      else
      {
         if (trend[whichBar] != trend[whichBar+1])
         if (trend[whichBar] == 1)
               doAlert("leaving oversold");
         else  doAlert("leaving overbought");       
      }         
   }
   
   return(0);
}

//+------------------------------------------------------------------+
//
//
//
//


void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," Robby DSS Bressert ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," Robby DSS Bressert "),message);
             if (alertsSound)   PlaySound(soundfile);
      }
}

      